==> jc-1.4.0.tar.gz: java/security/cert/CertificateParsingException.h <==
// public class java.security.cert.CertificateParsingException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 692089051f4c8d0b java_security_GeneralSecurityException
// @dep_class ebfb598dd9fa8080 java_security_cert_CertificateException
// @dep_class e727c101a9f26795 java_security_cert_CertificateParsingException

// header file dependencies
// @dep_header java_security_cert_CertificateException

#include "java/security/cert/CertificateException.h"

#ifndef _JC_java_security_cert_CertificateParsingException_H_
#define _JC_java_security_cert_CertificateParsingException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_security_cert_CertificateParsingException$sub_refs	_jc_java_security_cert_CertificateParsingException$sub_refs;
typedef struct _jc_java_security_cert_CertificateParsingException$sub_nonrefs	_jc_java_security_cert_CertificateParsingException$sub_nonrefs;
typedef struct _jc_java_security_cert_CertificateParsingException$refs	_jc_java_security_cert_CertificateParsingException$refs;
typedef struct _jc_java_security_cert_CertificateParsingException$nonrefs	_jc_java_security_cert_CertificateParsingException$nonrefs;
typedef struct _jc_java_security_cert_CertificateParsingException$object	_jc_java_security_cert_CertificateParsingException$object;

typedef struct _jc_java_security_cert_CertificateParsingException$fields_struct	_jc_java_security_cert_CertificateParsingException$fields_struct;
typedef const struct _jc_java_security_cert_CertificateParsingException$vmethods	_jc_java_security_cert_CertificateParsingException$vmethods;
typedef const struct _jc_java_security_cert_CertificateParsingException$vtable	_jc_java_security_cert_CertificateParsingException$vtable;
typedef const struct _jc_java_security_cert_CertificateParsingException$vtype	_jc_java_security_cert_CertificateParsingException$vtype;

// Class fields structure
struct _jc_java_security_cert_CertificateParsingException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_cert_CertificateParsingException$fields_struct _jc_java_security_cert_CertificateParsingException$class_fields;

// Constructors
extern void _jc_java_security_cert_CertificateParsingException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_cert_CertificateParsingException$object *);
extern void _jc_java_security_cert_CertificateParsingException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_security_cert_CertificateParsingException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_security_cert_CertificateParsingException$vmethods {
};

// Vtable
struct _jc_java_security_cert_CertificateParsingException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_security_GeneralSecurityException$vmethods	java_security_GeneralSecurityException;
	_jc_java_security_cert_CertificateException$vmethods	java_security_cert_CertificateException;
	_jc_java_security_cert_CertificateParsingException$vmethods	java_security_cert_CertificateParsingException;
};

// Vtype
struct _jc_java_security_cert_CertificateParsingException$vtype {
	_jc_type			type;
	_jc_java_security_cert_CertificateParsingException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_CertificateParsingException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_cert_CertificateParsingException$refs {
    _jc_java_security_cert_CertificateParsingException$sub_refs	java_security_cert_CertificateParsingException;
    _jc_java_security_cert_CertificateException$sub_refs	java_security_cert_CertificateException;
    _jc_java_security_GeneralSecurityException$sub_refs	java_security_GeneralSecurityException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_CertificateParsingException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_CertificateParsingException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_security_GeneralSecurityException$sub_nonrefs	java_security_GeneralSecurityException;
    _jc_java_security_cert_CertificateException$sub_nonrefs	java_security_cert_CertificateException;
    _jc_java_security_cert_CertificateParsingException$sub_nonrefs	java_security_cert_CertificateParsingException;
};

// Object instance structure
struct _jc_java_security_cert_CertificateParsingException$object {
	_jc_java_security_cert_CertificateParsingException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_CertificateParsingException$vtype	*vtype;
	_jc_java_security_cert_CertificateParsingException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_CertificateParsingException$vtype _jc_java_security_cert_CertificateParsingException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_CertificateParsingException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_CertificateParsingException$class_object;

#endif	/* _JC_java_security_cert_CertificateParsingException_H_ */

==> jc-1.4.6.tar.gz: java/security/cert/CertificateParsingException.h <==
// public class java.security.cert.CertificateParsingException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 692089051f4c8d0b java_security_GeneralSecurityException
// @dep_class ebfb598dd9fa8080 java_security_cert_CertificateException
// @dep_class e727c101a9f26795 java_security_cert_CertificateParsingException

// header file dependencies
// @dep_header java_security_cert_CertificateException

#include "java/security/cert/CertificateException.h"

#ifndef _JC_java_security_cert_CertificateParsingException_H_
#define _JC_java_security_cert_CertificateParsingException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_security_cert_CertificateParsingException$sub_refs	_jc_java_security_cert_CertificateParsingException$sub_refs;
typedef struct _jc_java_security_cert_CertificateParsingException$sub_nonrefs	_jc_java_security_cert_CertificateParsingException$sub_nonrefs;
typedef struct _jc_java_security_cert_CertificateParsingException$refs	_jc_java_security_cert_CertificateParsingException$refs;
typedef struct _jc_java_security_cert_CertificateParsingException$nonrefs	_jc_java_security_cert_CertificateParsingException$nonrefs;
typedef struct _jc_java_security_cert_CertificateParsingException$object	_jc_java_security_cert_CertificateParsingException$object;

typedef struct _jc_java_security_cert_CertificateParsingException$fields_struct	_jc_java_security_cert_CertificateParsingException$fields_struct;
typedef const struct _jc_java_security_cert_CertificateParsingException$vmethods	_jc_java_security_cert_CertificateParsingException$vmethods;
typedef const struct _jc_java_security_cert_CertificateParsingException$vtable	_jc_java_security_cert_CertificateParsingException$vtable;
typedef const struct _jc_java_security_cert_CertificateParsingException$vtype	_jc_java_security_cert_CertificateParsingException$vtype;

// Class fields structure
struct _jc_java_security_cert_CertificateParsingException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_cert_CertificateParsingException$fields_struct _jc_java_security_cert_CertificateParsingException$class_fields;

// Constructors
extern void _jc_java_security_cert_CertificateParsingException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_cert_CertificateParsingException$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_cert_CertificateParsingException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_security_cert_CertificateParsingException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_security_cert_CertificateParsingException$vmethods {
};

// Vtable
struct _jc_java_security_cert_CertificateParsingException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_security_GeneralSecurityException$vmethods	java_security_GeneralSecurityException;
	_jc_java_security_cert_CertificateException$vmethods	java_security_cert_CertificateException;
	_jc_java_security_cert_CertificateParsingException$vmethods	java_security_cert_CertificateParsingException;
};

// Vtype
struct _jc_java_security_cert_CertificateParsingException$vtype {
	_jc_type			type;
	_jc_java_security_cert_CertificateParsingException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_CertificateParsingException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_cert_CertificateParsingException$refs {
    _jc_java_security_cert_CertificateParsingException$sub_refs	java_security_cert_CertificateParsingException;
    _jc_java_security_cert_CertificateException$sub_refs	java_security_cert_CertificateException;
    _jc_java_security_GeneralSecurityException$sub_refs	java_security_GeneralSecurityException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_CertificateParsingException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_CertificateParsingException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_security_GeneralSecurityException$sub_nonrefs	java_security_GeneralSecurityException;
    _jc_java_security_cert_CertificateException$sub_nonrefs	java_security_cert_CertificateException;
    _jc_java_security_cert_CertificateParsingException$sub_nonrefs	java_security_cert_CertificateParsingException;
};

// Object instance structure
struct _jc_java_security_cert_CertificateParsingException$object {
	_jc_java_security_cert_CertificateParsingException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_CertificateParsingException$vtype	*vtype;
	_jc_java_security_cert_CertificateParsingException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_CertificateParsingException$vtype _jc_java_security_cert_CertificateParsingException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_CertificateParsingException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_CertificateParsingException$class_object;

#endif	/* _JC_java_security_cert_CertificateParsingException_H_ */
